@@ -79,8 +79,24 @@ sub theme_header
         print $tconfig{'preheader'};
         print '<div class="header">
                 <div class="row">';
+        # Title
+        my $ts =
+            defined($tconfig{'titlesize'}) ? $tconfig{'titlesize'} :
+            "+2";
+        print "<div data-current-module-name=\"$this_module_info{'desc'}\" id='headln2c' class=\"col-sm-4\">",
+            ($ts ? "<span data-main_title>" : ""), $ttitle, ($ts ? "</span>" : "");
+        print "<br><span data-main_title_sub>$_[9]</span>\n" if ($_[9]);
+        if ($theme_ui_post_header_text) {
+            print "<span data-sub_title><br>$theme_ui_post_header_text</span>";
+        } else {
+            print "<p class=\"margined-bottom-5\"></p>";
+        }
+        if ($_[1]) {
+            print "<br><img data-module-image alt=\"$ttitle\" src=\"$_[1]\">\n";
+        }
+        print "</div>\n"; # header-center
+        
         print '<div data-header-left id="headln2l" class="invisible col-sm-4">';
-
         if (!$_[5] && !$tconfig{'noindex'}) {
             my @avail = &get_available_module_infos(1);
             my $nolo  = get_env('anonymous_user') ||
@@ -135,24 +151,7 @@ sub theme_header
                 print "<a href=\"$theme_webprefix/$cprog?module=", &get_module_name().$params . "\">", $text{'header_config'}, "</a><br>\n";
             }
         }
-        print "</div>\n";
-        if ($_[1]) {
-            print "<div data-current-module-name=\"$this_module_info{'desc'}\" id=\"headln2c\" class=\"col-sm-4\">",
-              "<img alt=\"$ttitle\" src=\"$_[1]\"></td>\n";
-        } else {
-            my $ts =
-              defined($tconfig{'titlesize'}) ? $tconfig{'titlesize'} :
-              "+2";
-            print "<div data-current-module-name=\"$this_module_info{'desc'}\" id='headln2c' class=\"col-sm-4\">",
-              ($ts ? "<span data-main_title>" : ""), $ttitle, ($ts ? "</span>" : "");
-            print "<br><span data-main_title_sub>$_[9]</span>\n" if ($_[9]);
-            if ($theme_ui_post_header_text) {
-                print "<span data-sub_title><br>$theme_ui_post_header_text</span>";
-            } else {
-                print "<p class=\"margined-bottom-5\"></p>";
-            }
-            print "</div>\n";
-        }
+        print "</div>\n"; # header-left
         print "<div data-header-right id=\"headln2r\" class=\"col-sm-4\">";
         print $_[6];
         print "</div></div></div>\n";
@@ -193,8 +192,8 @@ sub theme_footer
             $url = "$theme_webprefix$url" if ($url =~ /^\//);
             $url = $url . "/"             if ($url =~ /[^\/]$/ && $url !~ /.cgi/ && $url !~ /javascript:history/ && $url !~ /[&?]/);
             print
-"<a style='margin-bottom: 15px;' class='btn btn-primary btn-lg page_footer_submit' href=\"$url\"><i class='fa fa-fw fa-arrow-left'>&nbsp;</i> <span>",
-              &text('main_return', $_[$i + 1]), "</span></a>\n";
+"<a style='margin-bottom: 10px;' class='btn btn-primary btn-lg page_footer_submit' href=\"$url\"><i class='fa fa-fw fa-arrow-left'>&nbsp;</i> <span>",
+              &text('main_return', $_[$i + 1]), "</span></a>&nbsp;&nbsp;\n";
         }
     }
 
@@ -551,7 +550,7 @@ sub theme_ui_help
 {
     my ($title) = @_;
     return (
-"<sup class=\"ui_help\" data-container=\"body\" data-placement=\"auto right\" data-title=\"$title\" data-toggle=\"tooltip\"><i class=\"fa fa-0_80x fa-question-circle cursor-help\"></i></sup>"
+"<sup class=\"ui_help\" data-container=\"body\" data-placement=\"auto right\" data-title=\"$title\" data-toggle=\"tooltip\"><i class=\"fa fa-question-circle cursor-help ui_help_icon\"></i></sup>"
     );
 }
 
@@ -1161,7 +1160,7 @@ sub theme_ui_table_end
 
 sub theme_ui_table_row
 {
-    my ($label, $value, $cols, $tds, $trs) = @_;
+    my ($label, $value, $cols, $tds, $trs, $force_full_width) = @_;
     $cols ||= 1;
     $tds  ||= $main::ui_table_default_tds;
     my $rv;
@@ -1179,7 +1178,7 @@ sub theme_ui_table_row
     my $trtags_attrs = ref($trs) eq 'ARRAY' && $trs->[0] ? " $trs->[0]" : "";
     $trtags_attrs .= " data-row-type='ui-table' data-cell-colspan='$cols'";
     $trtags_attrs .= ' data-column-span="all" data-column-locked="1"'
-      if ($cols == 2 && !length($label));
+      if (($cols == 2 && !length($label)) || $force_full_width);
     my $trtags_class = ref($trs) eq 'ARRAY' && $trs->[1] ? " class='$trs->[1]'" : "";
     $rv .= "<tr$trtags_class$trtags_attrs>\n"
       if ($main::ui_table_pos % $main::ui_table_cols == 0);
@@ -1308,6 +1307,7 @@ sub theme_ui_hidden_table_start
     my $defclass =
       $status ? 'opener_shown' :
       'opener_hidden';
+    my $trigger_class = $status == 1 ? 'opener_container_opened' : 'opener_container_closed';
     my $text =
       defined($tconfig{'cs_text'}) ? $tconfig{'cs_text'} :
       defined($gconfig{'cs_text'}) ? $gconfig{'cs_text'} :
@@ -1319,7 +1319,7 @@ sub theme_ui_hidden_table_start
         $rv .= "<tr" . ($tb ? " " . $tb : "") . "><td>";
         if (defined($heading)) {
             $rv .=
-"<a tabindex='-1' class='opener_trigger' href=\"javascript:hidden_opener('$divid', '$openerid')\" id='$openerid'></a> <a class='opener_trigger' href=\"javascript:hidden_opener('$divid', '$openerid')\">$heading</a></td>";
+"<a tabindex='-1' class='opener_trigger $trigger_class' href=\"javascript:hidden_opener('$divid', '$openerid')\" id='$openerid'></a> <a class='opener_trigger' href=\"javascript:hidden_opener('$divid', '$openerid')\">$heading</a></td>";
         }
         if (defined($rightheading)) {
             $rv .= "<td align=right>$rightheading</td>";
@@ -1329,7 +1329,7 @@ sub theme_ui_hidden_table_start
     }
     $rv .=
       "<tr" . ($cb ? " " . $cb : "") .
-      "><td class='opener_container' colspan=$colspan><div class='$defclass' id='$divid'><table width=100%>\n";
+      "><td class='opener_container panel-table-body' colspan=$colspan><div class='$defclass' id='$divid'><table width=100%>\n";
     $main::ui_table_cols        = $cols || 4;
     $main::ui_table_pos         = 0;
     $main::ui_table_default_tds = $tds;
@@ -1731,7 +1731,6 @@ sub theme_error
         return $error_stack;
     };
     if (!$main_header) {
-        print "<hr>\n";
         print "<h3 data-fatal-error-text>$error</h3>\n";
         print &$get_error_stack();
         print "<hr>\n";
